@@ -13,6 +13,18 @@ class Course:
     alias: Optional[str] = None
 
 
+@dataclass
+class GroupSet:
+    id: int
+    name: str
+
+
+@dataclass
+class Group:
+    id: int
+    name: str
+
+
 @dataclass
 class Student:
     id: int
