@@ -1,19 +1,18 @@
 import importlib.resources
 import pathlib
-import re
 
 import click
 import jinja2
 import tomli
-from rich import box, print
+from rich import box
 from rich.console import Console
 from rich.syntax import Syntax
 from rich.table import Table
 
-from canvas_course_tools.datatypes import GroupList, Student, StudentGroup
+from canvas_course_tools.datatypes import GroupList
+from canvas_course_tools.group_lists import parse_group_list
 
 TEMPLATE_INFO_FILE = "template-info.toml"
-PARSE_STUDENT_RE = re.compile("(?P<name>.*) \((?P<id>.*)\) *(?:\[(?P<notes>.*)\])?")
 
 
 @click.group()
@@ -35,8 +34,9 @@ def list_templates():
     for template in sorted(template_files.iterdir()):
         if template.is_file() and not template == info_file:
             table.add_row(template.name, info.get(template.name, ""))
-    print()
-    print(table)
+    console = Console()
+    console.print()
+    console.print(table)
 
 
 @templates.command("show")
@@ -90,7 +90,7 @@ def render_template(template, group_list, file, auto_write, output_dir):
     to get a list of included templates.
 
     The second argument, GROUP_LIST, should be a path to a group list file. If a
-    file starts with a #-character, the rest of the line is interpreted as a
+    line starts with a #-character, the rest of the line is interpreted as a
     title. If it starts with ##, the rest of the line is interpreted as a group
     name. There can be multiple groups defined in one file. All other non-empty
     lines are interpreted as a student name with optional student id and notes
@@ -166,38 +166,6 @@ def build_output_path(file, output_dir, template, group_list):
     return path
 
 
-def parse_group_list(text):
-    """Parse text and build a group list."""
-    group_list = GroupList()
-    current_group = StudentGroup()
-
-    for line in text.splitlines():
-        if not line:
-            # empty line
-            continue
-        elif line.startswith("##"):
-            # new group name
-            group_name = line.removeprefix("##").strip()
-            if current_group.students:
-                # there are students in the current group, add them to the list
-                group_list.groups.append(current_group)
-            # create new group
-            current_group = StudentGroup(name=group_name)
-        elif line.startswith("#"):
-            # group list name
-            group_list.name = line.removeprefix("#").strip()
-        else:
-            # must be a student
-            match = PARSE_STUDENT_RE.match(line)
-            if match:
-                current_group.students.append(
-                    Student(name=match["name"], id=match["id"], notes=match["notes"])
-                )
-    group_list.groups.append(current_group)
-
-    return group_list
-
-
 def render_template(template_name, group_list: GroupList):
     """Render a template.
 
